<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Todos os arquivos (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Modo avião</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Interromper comunicação sem fio</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Habilitar modo avião e desligar rede sem fio, hotspot pessoal e Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de Aplicação</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurar servidores proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP Inválido</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Porta Inválida</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de Usuário</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Marque &quot;Usar um proxy&quot; no menu de contexto do aplicativo no Launcher após a configuração</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Configurar conexão de rede discada</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Adicionar Conexão PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propriedades de Rede</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Você tem certeza que quer apagar essa configuração?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Detalhes de Rede</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Visualizar todas as configurações de rede</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Os detalhes foram copiados</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecionar Tudo</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Detectar Rede</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Não vinculado</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot pessoal</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Compartilhar a Rede</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Meu Hotspot</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Editar Meu Hotspot</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nome (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Configuração Compartilhada</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Dispositivo de compartilhamento de ponto de acesso</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Se você quiser usar o ponto de acesso pessoal, desative o Modo Avião primeiro e depois ative o adaptador de rede sem fio.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Se você quiser usar o hotspot pessoal, desative&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt; o modo avião&lt;/a&gt;primeiro e depois habilite o adaptador de rede sem fio.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propriedades da Rede</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Tem certeza de que deseja excluir esta configuração?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurar servidores proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de Configuração</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignore as configurações de proxy para os hosts e domínios acima</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Conectar, adicionar, importar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Adicionar VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Erro ao importar</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erro de arquivo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propriedades de Rede</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Tem certeza de que deseja excluir esta configuração?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Conectar, editar configurações de rede</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Conecte o cabo de rede primeiro</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adicionar conexão de rede</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Conectar, editar configurações de rede</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Minhas redes</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Outras redes</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Desative o Modo Avião primeiro se quiser se conectar a uma rede sem fio</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Desative&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt; o Modo Avião&lt;/a&gt; primeiro se quiser se conectar a uma rede sem fio</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desative o hotspot primeiro se quiser se conectar a uma rede sem fio</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Desative o hotspot&lt;/a&gt; primeiro se quiser se conectar a uma rede sem fio</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP inválido</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Não vinculado</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Endereço MAC do dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Endereço MAC clonado</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar uma MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nome (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conexão automática</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desabilitado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplicado somente em recursos correspondentes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP inválido</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de sub-rede inválida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço IP duplicado</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplicado somente em recursos correspondentes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP inválido</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de sub-rede inválida</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço IP duplicado</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Status MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sem compressão de dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sem compressão de dados deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sem compressão de cabeçalho TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar pacotes PPP Echo</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>RÁPIDA</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS em túnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegido</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation>GTC</translation>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation>MSCHAPV2</translation>
    </message>
    <message>
        <source>PAP</source>
        <translation>PAP</translation>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Pessoal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Empresarial</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Pessoal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticação EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de senha</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Salvar senha para este usuário</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Salvar senha para todos os usuários</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Sempre perguntar</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Senha privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Chave compartilhada</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistema aberto</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anônimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisionando</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anônimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Arquivo PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versão PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versão 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versão 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticação Interna</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Todos os arquivos (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir Trojan Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticação</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Cartão inteligente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave pré-compartilhada</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de Usuário</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Use FSID para frase-senha de chave</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados com Senha (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chave estática</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de senha</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvo</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não necessário</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Senha privada</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Direção da chave personalizada</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direção da Chave</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Remoto</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Local</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domínio NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar um endereço de IP interno</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Reforçar o Encapsulamento UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usar compactação IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Habilitar propostas de cifra personalizadas</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome do grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Senha do grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usar autenticação híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Arquivo CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Todas disponíveis (padrão)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos seguro)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (mais seguro)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Status MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sem compressão de dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sem compressão de dados deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sem compressão de cabeçalho TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sem compressão de campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sem compressão de endereço/controle</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar pacotes PPP Echo</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Habilitar IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID do grupo</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmos da Fase 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmos da Fase 2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avançada</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalizar a Porta do Gateway</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Porta do Gateway</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalizar intervalo de renegociação</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo de Renegociação</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Usar compressão de dados LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usar conexão TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usar dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalizar MTU do túnel</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizar tamanho do fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamanho do fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringir o Túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Randomizar hosts remotos</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domínio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Fornecedor</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (padrão)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Tela de rede</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Criptografia</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Seguro (padrão)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Fraca</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo de Travessia NAT</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T quando disponível (padrão)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T sempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Grupo DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Grupo DH 2 (padrão)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Grupo DH 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Encaminhamento sigiloso</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (padrão)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Grupo DH 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Porta Local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Desativar detecção de pares mortos</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Segurança VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifra</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation>DES-CBC</translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation>RC2-CBC</translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation>DES-EDE-CBC</translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation>DES-EDE3-CBC</translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation>DESX-CBC</translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation>BF-CBC</translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation>RC2-40-CBC</translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation>CAST5-CBC</translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation>RC2-64-CBC</translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation>AES-128-CBC</translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation>AES-192-CBC</translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation>AES-256-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation>CAMELLIA-128-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation>CAMELLIA-192-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation>CAMELLIA-256-CBC</translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation>SEED-CBC</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticação HMAC</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Tentar novamente indefinidamente quando falhar</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticação VPN TLS</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Assunto Relacionado</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de Certificado Remoto</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Arquivo chave</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>É necessária autenticação</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Primeiro, desative o &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Modo Avião&lt;/a&gt; para conectar-se a uma rede Wi-Fi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexão cabeada %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexão PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Conectando &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>“%1” conectado</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; desconectado</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Impossível conectar-se a %1, verifique os dispositivos de rede.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Impossível conectar-se a %1, aproxime-se do roteador Wi-Fi</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>A conexão falhou, impossível conectar-se a &quot;%1&quot; pois a senha está incorreta</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>A senha é necessária para conectar-se a “%1”</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Impossível encontrar a rede Wi-Fi &quot;%1&quot;</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Para conectar-se a “%1”, configure suas informações de autenticação após fazer login</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>A configuração de VPN não está conectada ou falhou ao conectar-se. Acesse a &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Central de Controle&lt;/a&gt; para verificar.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede cabeada</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede Wi-Fi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar-se a rede oculta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Minhas redes</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Outras redes</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
</TS>